@@ -1,9 +1,9 @@
 package Test::Smoke::Smoker;
 use strict;
 
-# $Id: Smoker.pm 1192 2008-08-09 00:55:05Z abeltje $
+# $Id: Smoker.pm 1198 2008-08-14 14:00:49Z abeltje $
 use vars qw( $VERSION );
-$VERSION = '0.040';
+$VERSION = '0.041';
 
 use Cwd;
 use File::Spec::Functions qw( :DEFAULT abs2rel rel2abs );
@@ -882,7 +882,7 @@ sub _transform_testnames {
     my( $self, @notok ) = @_;
     my %inconsistent;
     for my $nok ( @notok ) {
-        $nok =~ m!^(?:\.\.[\\/])?(\w+[\\/][-\w/\\]+)\.*(.*)! or next;
+        $nok =~ m!^((?:\.\.[\\/])?\w+[\\/][-\w/\\]+)\.*(.*)! or next;
         my( $test_name, $status ) = ( $1, $2 );
 
         my $test_path = $self->_normalize_testname( $test_name );
@@ -903,13 +903,14 @@ sub _normalize_testname {
 
     $test_name =~ s/\s+$//;
     $test_name =~ /\.t$/ or $test_name .= '.t';
-    $test_name = $test_name =~ /^(?:ext|lib|t)\b/
-        ? catfile( updir(), $test_name )
-        : catfile( updir(), 't', $test_name );
-
+    if ( $test_name !~ m|^\Q../| ) {
+        $test_name = $test_name =~ /^(?:ext|lib|t)\b/
+            ? catfile( updir(), $test_name )
+            : catfile( updir(), 't', $test_name );
+    }
     my $test_base = catdir( $self->{ddir}, 't' );
     $test_name = rel2abs( $test_name, $test_base );
-
+    
     my $test_path = abs2rel( $test_name, $test_base );
     $test_path =~ tr!\\!/! if $self->{is_win32};
 
